@@ -40,7 +40,7 @@ if (OpenID::GetConfigBool('openid.ca.override')) {
     define('Auth_OpenID_CURLOPT_CAINFO', $config['root_path'] . '/modules/OpenID/cacert.pem');
 }
 
-define('OpenIDModule_OPENID_DIR', 'openid-php-openid-782224d/');
+define('OpenIDModule_OPENID_DIR', 'openid-php-openid-d4e5efe/');
 
 $path_extra = dirname(dirname(dirname(__FILE__)));
 $path = ini_get('include_path');
@@ -50,7 +50,11 @@ ini_set('include_path', $path);
 require_once OpenIDModule_OPENID_DIR . "Auth/OpenID/Consumer.php";
 
 $dirname = dirname(__FILE__);
+
+// Can we depend on CMSMS autoloading of classes in older versions as well?
 require_once($dirname . DIRECTORY_SEPARATOR . 'lib/class.CMSMSDatabaseConnection.php');
+require_once($dirname . DIRECTORY_SEPARATOR . 'lib/class.OpenIDUtils.php');
+
 require_once OpenIDModule_OPENID_DIR . "Auth/OpenID/MySQLStore.php";
 
 require_once OpenIDModule_OPENID_DIR . "Auth/OpenID/SReg.php";
@@ -66,7 +70,7 @@ $pape_policy_uris = array(
 
 // Check if Facebook classes already loaded - user might have installed FeuFacebook module
 if (!class_exists('FacebookApiException')) {
-    require_once 'facebook_2_1_2/facebook.php';
+    require_once 'facebook_3_1_1/facebook.php';
 }
 
 class OpenID extends CMSModule {
@@ -82,7 +86,7 @@ class OpenID extends CMSModule {
     }
 
     function GetVersion() {
-        return '1.2.1';
+        return '1.3.0';
     }
 
     function GetHelp() {
@@ -362,8 +366,7 @@ class OpenID extends CMSModule {
      * @return <type>
      */
     function DisplayProvider($provider) {
-        $preference = $this->GetPreference('enable_provider_' . $provider, '0');
-        return!empty($preference);
+        return OpenIDUtils::IsEnabled($provider, $this);
     }
 
     /**
@@ -419,12 +422,11 @@ class OpenID extends CMSModule {
         $facebook = new Facebook(array(
                     'appId' => $this->GetPreference('facebook_app_id', ''),
                     'secret' => $this->GetPreference('facebook_app_secret', ''),
-                    'cookie' => true,
                 ));
         // Fix: Remove xml encoded amps before passing to facebook library
         $loginUrl = $facebook->getLoginUrl(array(
-                    'cancel_url' => str_replace('amp;', '', $currentUrl),
-                    'next' => str_replace('amp;', '', $next)));
+                    'scope' => '',
+                    'redirect_uri' => str_replace('amp;', '', $next)));
         // Fix: Replace amps in order to be xhtml compliant
         $loginUrl = str_replace('&', '&amp;', $loginUrl);
         $this->Log('FacebookLoginUrl : ' . $loginUrl);
