@@ -21,11 +21,15 @@
 /* @var $this OpenID */
 /* @var $gCms CmsObject */
 
-function CreateProviderInput($provider, $module, $default = 1) {
+function CreateProviderInput($provider, $module, $enabled = TRUE) {
     global $smarty;
+    $id = null;
+    $checkbox = RRUtils::myCreateInputCheckbox($id, 'input_provider_'.$provider, 1, OpenIDUtils::IsEnabled($provider, $module));
+    if (!$enabled) {
+        $checkbox = str_replace('type=','disabled type=', $checkbox);
+    }
     $smarty->assign('input_'.$provider,
-		RRUtils::myCreateInputCheckbox($id, 'input_provider_'.$provider, 1,
-					       $module->GetPreference('enable_provider_'.$provider,$default)));
+		$checkbox);
 }
 
 $smarty->assign('startform',
@@ -38,9 +42,11 @@ CreateProviderInput('aol', $this);
 CreateProviderInput('myopenid', $this);
 CreateProviderInput('myspace', $this);
 CreateProviderInput('flickr', $this);
-CreateProviderInput('facebook', $this, 0);
-CreateProviderInput('twitter', $this, 0);
-CreateProviderInput('twitter_small', $this, 0);
+$facebookConfigured = strlen($this->GetPreference('facebook_app_id','')) + strlen($this->GetPreference('facebook_app_secret','')) > 0;
+CreateProviderInput('facebook', $this, $facebookConfigured);
+$twitterConfigured = strlen($this->GetPreference('twitter_consumer_key','')) + strlen($this->GetPreference('twitter_consumer_secret','')) > 0;
+CreateProviderInput('twitter', $this, $twitterConfigured);
+CreateProviderInput('twitter_small', $this, $twitterConfigured);
 CreateProviderInput('technorati', $this);
 CreateProviderInput('wordpress', $this);
 CreateProviderInput('blogger', $this);
