@@ -7,11 +7,7 @@ $lang['uninstalled'] = 'Module Uninstalled.';
 $lang['installed'] = 'Module version %s installed.';
 $lang['upgraded'] = 'Module upgraded to version %s.';
 $lang['moddescription'] = 'This module adds OpenID login capabilities to CMS Made Simple and FrontEndUsers.';
-$lang['changelog'] = '<ul>
-<li>Version 1.0.0 First public release with support for OpenID and Facebook authentication</li>
-<li>Version 1.1.0 Added support for Twitter authentication. Possible to configure redirects after login. Added <a href="http://code.google.com/p/openid-selector/">OpenID Selector</a> as additional OpenID login page style.
-<li>Version 1.2.0 Module can co-exist with FeuFacebook (<a href="http://dev.cmsmadesimple.org/bug/view/6192">issue 6192</a>). Solved redirects to admin page in some scenarios (reported <a href="http://forum.cmsmadesimple.org/viewtopic.php?f=7&t=56088">here</a>).
-</ul>';
+$lang['changelog'] = 'See wiki at <a href="https://bitbucket.org/henriklen/openid/wiki/">https://bitbucket.org/henriklen/openid/wiki/</a>';
 $lang['help'] = '<h3>What Does This Do?</h3>
 <p>The OpenID module provides functionality to add an OpenID or Facebook account to a registered frontend user. That user can then log in using that identity instead of the ordinary frontend account.</p>
 <h3>How Do I Use It</h3>
@@ -26,6 +22,7 @@ $lang['help'] = '<h3>What Does This Do?</h3>
     <li>Revisit the page with the OpenID tag, select the same provider you just registered, authenticate and behold: You are now logged in</li>
 </ol></p>
 <h3>Support</h3>
+<p>Check out the wiki for FAQ and additional information: <a href="https://bitbucket.org/henriklen/openid/wiki/">https://bitbucket.org/henriklen/openid/wiki/</a><p>
 <p>Getting OpenID to work properly can be a bit of a struggle if you are not
 fortunate enough to have an environment that already has all the bits and pieces in place.
 <br/>Some places to check before asking for help:<br/>
@@ -44,13 +41,13 @@ fortunate enough to have an environment that already has all the bits and pieces
 <ul>
     <li><a href="http://github.com/openid/php-openid/" target="_blank">PHP OpenID library by JanRain, Inc.</a></li>
     <li><a href="http://jvance.com/pages/JQueryOpenIDPlugin.xhtml" target="_blank">OpenID jQuery plugin by Jarret Vance</a></li>
-    <li><a href="https://github.com/facebook/php-sdk/" target="_blank">Facebook PHP SDK</a></li>
+    <li><a href="https://github.com/facebook/facebook-php-sdk" target="_blank">Facebook PHP SDK</a></li>
     <li><a href="http://www.jquery.com" target="_blank">jQuery</a></li>
 </ul>
 </p>
 
 <h3>Copyright and License</h3>
-<p>Copyright &copy; 2010-2011, <a href="mailto:openid@lennartssons.net">Henrik Lennartsson</a>. All Rights Are Reserved.</p>
+<p>Copyright &copy; 2010-2012, <a href="mailto:openid@lennartssons.net">Henrik Lennartsson</a>. All Rights Are Reserved.</p>
 <p>This module has been released under the <a href="http://www.apache.org/licenses/LICENSE-2.0.html">Apache License Version 2.0</a>. You must agree to this license before using the module.</p>
 ';
 $lang['openid_providers'] = 'Enabled providers';
